@@ -210,12 +210,14 @@ class ErrorFactory:
             'resource': resource,
             'retry_delay': retry_delay,
             'retry_times': retry_times,
-            'documentation_url': error_url
+            'documentation_url': error_url,
+            'request': api_response.request,
+            'response': api_response.response
         }
 
         if kind == ScrapflyError.KIND_HTTP_BAD_RESPONSE:
             if http_code >= 500:
-                return ApiHttpServerError(**args, request=api_response.request, response=api_response.response)
+                return ApiHttpServerError(**args)
 
             if http_code in ErrorFactory.HTTP_STATUS_TO_ERROR:
                 return ErrorFactory.HTTP_STATUS_TO_ERROR[http_code](**args)
@@ -225,12 +227,19 @@ class ErrorFactory:
         elif kind == ScrapflyError.KIND_SCRAPFLY_ERROR:
             if code == 'ERR::SCRAPE::BAD_UPSTREAM_RESPONSE':
                 if http_code >= 500:
-                    return UpstreamHttpServerError(**args, request=api_response.request, response=api_response.response)
+                    return UpstreamHttpServerError(**args)
 
                 if resource in ErrorFactory.RESOURCE_TO_ERROR:
+
+                    del args['request']
+                    del args['response']
+
                     return ErrorFactory.RESOURCE_TO_ERROR[resource](**args)
 
-                return UpstreamHttpClientError(**args, request=api_response.request, response=api_response.response)
+                return UpstreamHttpClientError(**args)
+
+            del args['request']
+            del args['response']
 
             return ScrapflyError(**args)
 
